==> wls-plugin-1.2.1-sources.jar: com/xebialabs/deployit/plugin/wls/step/DestroyWlsJmsServerStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of Xebialabs Software and Documentation is subject to the Personal
 * License Agreement.
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the Xebialabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.plugin.wls.ci.WlsJmsServer;
import com.xebialabs.deployit.plugin.wls.ci.WlsServer;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsModule;

/**
 * Deletes a {@link WlsJmsServer foreign JMS server}.
 */
@SuppressWarnings("serial")
public class DestroyWlsJmsServerStep extends SimpleWlstExecutingStep {

	public static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "destroy-jms-server.py";

	public DestroyWlsJmsServerStep(WlsServer server, WlsJmsServer jmsServer, WlsJmsModule module) {
		super("Destroy JMS Servers " + jmsServer + "for Servers in Cluster " + server, server.getDomain(), SCRIPT_RESOURCE_PATH, getArgs(module, jmsServer));
	}

	private static String[] getArgs(WlsJmsModule module, WlsJmsServer jmsServer) {
		List<String> args = new ArrayList<String>();
		args.add(module.getName());
		args.add(jmsServer.getName());
		args.add(jmsServer.getName() + "-filestore");
		return args.toArray(new String[args.size()]);
	}

}

==> wls-plugin-1.3-sources.jar: com/xebialabs/deployit/plugin/wls/step/DestroyWlsJmsServerStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsServer;

/**
 * Destroys a {@link WlsJmsServer}.
 */
@SuppressWarnings("serial")
public class DestroyWlsJmsServerStep extends SimpleWlstExecutingStep {

	public static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "destroy-jms-server.py";

	public DestroyWlsJmsServerStep(WlsDomain domain, WlsJmsServer jmsServer) {
		super("Destroy JMS Server " + jmsServer + " on domain " + domain, domain, SCRIPT_RESOURCE_PATH, jmsServer.getName(), jmsServer.getFileStoreName());
	}

}
